pub struct Touchscreen { /* private fields */ }Expand description
Touch input device. Touch emulation is enabled once, lazily, on the first
Touchscreen::tap; the enabled flag is shared across all clones produced
from the same page (mirroring Playwright’s persistent page.touchscreen()).
Implementations
Sourceimpl Touchscreen
impl Touchscreen