AriaRole

Enum AriaRole 

pub enum AriaRole {
Show 83 variants Alert, Alertdialog, Application, Article, Banner, Blockquote, Button, Caption, Cell, Checkbox, Code, Columnheader, Combobox, Complementary, Contentinfo, Definition, Deletion, Dialog, Directory, Document, Embed, Figure, Footer, Form, Generic, Grid, Gridcell, Group, Heading, Img, Image, Insertion, Link, List, Listbox, Listitem, Log, Main, Marquee, Math, Menu, Menubar, Menuitem, Menuitemcheckbox, Menuitemradio, Meter, Navigation, None, Note, Option, Paragraph, Presentation, Progressbar, Radio, Radiogroup, Region, Row, Rowgroup, Rowheader, Scrollbar, Search, Searchbox, Separator, Slider, Spinbutton, Status, Strong, Subscript, Superscript, Switch, Tab, Table, Tablist, Tabpanel, Term, Textbox, Time, Timer, Toolbar, Tooltip, Tree, Treegrid, Treeitem,
}
An ARIA role, used by get_by_role.

Mirrors Playwright’s AriaRole set.

Variants



Alert



Alertdialog



Application



Article



Banner



Blockquote



Button



Caption



Cell



Checkbox



Code



Columnheader



Combobox



Complementary



Contentinfo



Definition



Deletion



Dialog



Directory



Document



Embed



Figure



Footer



Form



Generic



Grid



Gridcell



Group



Heading



Img



Image



Insertion



List



Listbox



Listitem



Log



Main



Marquee



Math



Menu



Menubar



Menuitem



Menuitemcheckbox



Menuitemradio



Meter



Navigation



None



Note



Option



Paragraph



Presentation



Progressbar



Radio



Radiogroup



Region



Row



Rowgroup



Rowheader



Scrollbar



Search



Searchbox



Separator



Slider



Spinbutton



Status



Strong



Subscript



Superscript



Switch



Tab



Table



Tablist



Tabpanel



Term



Textbox



Time



Timer



Toolbar



Tooltip



Tree



Treegrid



Treeitem

Implementations

Source

impl AriaRole

pub fn as_str(&self) -> &'static str