pub struct Route { /* private fields */ }Expand description
An intercepted network request, paused in the Fetch domain.
Implementations
Sourceimpl Route
impl Route
Sourcepub async fn continue_(
&self,
options: Option<RouteContinueOptions>,
) -> Result<()>
pub async fn continue_( &self, options: Option<RouteContinueOptions>, ) -> Result<()>
Let the request proceed (optionally overriding url/method/headers/body).
Sourcepub async fn fallback(&self) -> Result<()>
pub async fn fallback(&self) -> Result<()>
Let the request proceed to the next matching route (no-op if only one).
Sourcepub async fn fulfill(&self, options: RouteFulfillOptions) -> Result<()>
pub async fn fulfill(&self, options: RouteFulfillOptions) -> Result<()>
Serve a synthetic response.